@@ -1,7 +1,7 @@
 funSim.fun <-
-function(i,lambda,fun.name,fun.args=NULL,n=100)
+function(i,lambda,fun.name,fun.args=NULL)
 {
-posNH<-simNHP.fun(lambda=lambda, n=n)$posNH
+posNH<-simNHP.fun(lambda=lambda)$posNH
   fun.args <- c(list(posNH), fun.args)
 aux<-do.call(fun.name,fun.args)
 return(aux)
